@@ -2,8 +2,8 @@ require 'spec_helper_acceptance'
 
 describe 'with file recursive purge' do
   basedir = default.tmpdir('concat')
-  context 'should still create concat file' do
-    pp = <<-EOS
+  context 'when run should still create concat file' do
+    pp = <<-MANIFEST
       file { '#{basedir}/bar':
         ensure => directory,
         purge  => true,
@@ -19,19 +19,18 @@ describe 'with file recursive purge' do
         target => 'foobar',
         content => 'foo',
       }
-    EOS
+    MANIFEST
 
     it 'applies the manifest twice with no stderr' do
-      apply_manifest(pp, :catch_failures => true)
-      apply_manifest(pp, :catch_changes => true)
+      apply_manifest(pp, catch_failures: true)
+      apply_manifest(pp, catch_changes: true)
     end
 
     describe file("#{basedir}/bar/foobar") do
-      it { should be_file }
-      its(:content) {
-        should match 'foo'
-      }
+      it { is_expected.to be_file }
+      its(:content) do
+        is_expected.to match 'foo'
+      end
     end
   end
 end
-
